import Account from './account'
import Balance from './balance'
import Block from './block'
import Channel from './channel'
import Council from './council'
import Era from './era'
import Event from './event'
import Proposal from './proposal'
import Member from './member'
import Category from './category'
import Thread from './thread'
import Post from './post'

Account.belongsTo(Member)
Account.hasMany(Balance)

Balance.belongsTo(Account)
Balance.belongsTo(Era)

Era.hasMany(Balance)
Era.hasMany(Block)

Block.belongsTo(Era)
Block.belongsTo(Member, { as: 'author' })
Block.hasMany(Event)

Council.hasMany(Member, { as: 'seat' })

Channel.belongsTo(Member, { as: 'owner' })

Category.hasMany(Thread)
Category.belongsTo(Member, { as: 'moderator' })

Thread.belongsTo(Category)
Thread.belongsTo(Member, { as: 'author' })
Thread.belongsTo(Member, { as: 'moderator' })
Thread.hasMany(Post)

Post.belongsTo(Thread)
Post.belongsTo(Member, { as: 'author' })

export {
  Account,
  Balance,
  Block,
  Channel,
  Council,
  Era,
  Event,
  Member,
  Proposal,
  Category,
  Thread,
  Post,
}
